PahoBroker

Struct PahoBroker 

pub struct PahoBroker {
    pub(crate) child: Child,
    pub(crate) port: u16,
    pub(crate) config_path: PathBuf,
}
A handle to a running Paho MQTT v5 test broker.

On drop, the broker process is killed and the temporary config file is removed.

Fields

child: Childport: u16config_path: PathBuf

Implementations



impl PahoBroker

pub fn start(config: &BrokerConfig) -> Self

Start a broker with the given config entries.

Panics

Panics if the broker fails to start or become reachable within 10 s.

pub fn start_on_port(config: &BrokerConfig, port: u16) -> Self

Start a broker on the given port.

Panics

Panics if the broker fails to start or become reachable within 10 s.

pub const fn port(&self) -> u16

The TCP port the broker is listening on.

pub(crate) fn wait_until_ready(&mut self)

Wait for the broker to accept TCP connections.

pub(crate) fn drain_stderr(&mut self) -> String